# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2018 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
Model for Base layer resources
"""

from flask_restful_swagger_2 import Schema

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Carmen Tawalika"
__copyright__ = (
    "Copyright 2016-2021, Sören Gebbert and mundialis GmbH & Co. KG"
)
__maintainer__ = "mundialis"


class SetRegionModel(Schema):
    """This schema represents the computational region definition for raster
    and vector map layers.

       n : for north
       s : for south
       e : for east
       w : for west
       res : resolution of the region
       ewres: east-west resolution
       nsres: north-south resolution
       raster: Raster layer name with mapset to set the region from
       align: Raster layer name with mapset to align the region to
       zoom: Raster layer name with mapset to zoom the region to
       vector: Vector layer name with mapset to set the region from

    """

    type = "object"
    properties = {
        "region": {
            "type": "string",
            "description": "Set current region from named region",
        },
        "raster": {
            "type": "string",
            "description": "Raster layer name with mapset to set the region from",
        },
        "align": {
            "type": "string",
            "description": "Raster layer name with mapset to align the region to",
        },
        "zoom": {
            "type": "string",
            "description": "Raster layer name with mapset to zoom the region to",
        },
        "vector": {
            "type": "string",
            "description": "Vector layer name with mapset to set the region from",
        },
        "n": {
            "type": "number",
            "format": "double",
            "description": "Value for the northern edge",
        },
        "s": {
            "type": "number",
            "format": "double",
            "description": "Value for the southern edge",
        },
        "w": {
            "type": "number",
            "format": "double",
            "description": "Value for the western edge",
        },
        "e": {
            "type": "number",
            "format": "double",
            "description": "Value for the eastern edge",
        },
        "t": {
            "type": "number",
            "format": "double",
            "description": "Value for the top edge",
        },
        "b": {
            "type": "number",
            "format": "double",
            "description": "Value for the bottom edge",
        },
        "nsres": {
            "type": "number",
            "format": "double",
            "description": "North-south 2D grid resolution",
        },
        "res": {
            "type": "number",
            "format": "double",
            "description": "2D grid resolution (north-south and east-west)",
        },
        "ewres": {
            "type": "number",
            "format": "double",
            "description": "East-west 2D grid resolution",
        },
        "res3": {
            "type": "number",
            "format": "double",
            "description": "3D grid resolution (north-south, east-west and top-bottom)",
        },
        "tbres": {
            "type": "number",
            "format": "double",
            "description": "Top-bottom 3D grid resolution",
        },
    }



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2021 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
Models for api_log_management
"""

from flask_restful_swagger_2 import Schema

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Carmen Tawalika"
__copyright__ = (
    "Copyright 2016-2021, Sören Gebbert and mundialis GmbH & Co. KG"
)
__maintainer__ = "mundialis"


class ApiLogEntryModel(Schema):
    """Response schema for a single API log entry that is used to track all API
    calls of a user.
    """

    type = "object"
    properties = {
        "time_stamp": {
            "type": "string",
            "description": "The time stamp of the API call",
        },
        "node": {
            "type": "string",
            "description": "The node that executed the API call",
        },
        "endpoint": {
            "type": "string",
            "description": "The endpoint of the API call",
        },
        "method": {
            "type": "string",
            "description": "The HTTP method of the request",
        },
        "path": {
            "type": "string",
            "description": "The path of the REST API call",
        },
        "url": {"type": "string", "description": "The request URL"},
        "request_str": {"type": "string", "description": "The request string"},
    }
    required = [
        "time_stamp",
        "node",
        "endpoint",
        "method",
        "path",
        "url",
        "request_str",
    ]


class ApiLogListModel(Schema):
    """Response schema that represents a list of API log entries."""

    type = "object"
    properties = {
        "api_log_list": {
            "type": "array",
            "items": ApiLogEntryModel,
            "description": "A list of ApiLogEntryModel objects",
        }
    }
    required = ["api_log_list"]



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2021 mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
Process Chain Monitoring
"""
from flask_restful_swagger_2 import Schema

__license__ = "GPLv3"
__author__ = "Anika Weinmann, Carmen Tawalika"
__copyright__ = "Copyright 2021, mundialis GmbH & Co. KG"
__maintainer__ = "mundialis"


class MapsetSizeResponseModel(Schema):
    """Response schema for mapset sizes of a resource"""

    type = "object"
    properties = {
        "status": {
            "type": "string",
            "description": "The status of the resource, values: success, error",
        },
        "mapset_sizes": {
            "type": "array",
            "items": {"type": "integer"},
            "description": "The list of mapset sizes of a resource in bytes",
        },
    }
    example = {"mapset_sizes": [29946, 29946], "status": "success"}
    required = ["status", "mapset_sizes"]


class MaxMapsetSizeResponseModel(Schema):
    """Response schema for maximum mapset size of a resoucre"""

    type = "object"
    properties = {
        "status": {
            "type": "string",
            "description": "The status of the resource, values: success, error",
        },
        "max_mapset_size": {
            "type": "integer",
            "description": "The maximum mapset size of a resource in bytes",
        },
    }
    example = {"max_mapset_size": 29949, "status": "success"}
    required = ["status", "max_mapset_size"]



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2022 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
API docs for user_management
"""

from actinia_core.models.response_models import (
    UserInfoResponseModel,
    UserListResponseModel,
    SimpleResponseModel,
)

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Anika Weinmann"
__copyright__ = "Copyright 2016-2022, mundialis GmbH & Co. KG"
__maintainer__ = "mundialis GmbH & Co. KG"

user_list_get_doc = {
    "tags": ["User Management"],
    "description": "Get a list of all users. "
    "Minimum required user role: admin.",
    "responses": {
        "200": {
            "description": "This response returns a list of user names.",
            "schema": UserListResponseModel,
        }
    },
}

user_get_doc = {
    "tags": ["User Management"],
    "description": "Get information about the group, role and permissions "
    "of a certain user. "
    "Minimum required user role: admin.",
    "parameters": [
        {
            "name": "user",
            "description": "The unique name of the user",
            "required": True,
            "in": "path",
            "type": "string",
        }
    ],
    "responses": {
        "200": {
            "description": "This response returns information about a "
            "certain user.",
            "schema": UserInfoResponseModel,
        },
        "400": {
            "description": "The error message",
            "schema": SimpleResponseModel,
        },
    },
}

user_post_doc = {
    "tags": ["User Management"],
    "description": "Creates a new user in the database. "
    "Minimum required user role: admin.",
    "parameters": [
        {
            "name": "user_id",
            "description": "The unique name of the user",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "password",
            "description": "The password of the new user",
            "required": True,
            "in": "query",
            "type": "string",
        },
        {
            "name": "group",
            "description": "The group of the new user",
            "required": True,
            "in": "query",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "This response returns the status of user "
            "creation.",
            "schema": SimpleResponseModel,
        },
        "400": {
            "description": "The error message",
            "schema": SimpleResponseModel,
        },
    },
}

user_delete_doc = {
    "tags": ["User Management"],
    "description": "Deletes a user. " "Minimum required user role: admin.",
    "parameters": [
        {
            "name": "user_id",
            "description": "The unique name of the user",
            "required": True,
            "in": "path",
            "type": "string",
        }
    ],
    "responses": {
        "200": {
            "description": "This response returns the status of user "
            "deletion.",
            "schema": SimpleResponseModel,
        },
        "400": {
            "description": "The error message",
            "schema": SimpleResponseModel,
        },
    },
}
